==> eclipse-platform-ui_4.15.orig.tar.xz: eclipse-platform-ui-4.15/tests/org.eclipse.ui.tests/Eclipse UI Tests/org/eclipse/ui/tests/keys/Bug43168Test.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2006 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ui.tests.keys;

import org.eclipse.jface.bindings.keys.KeySequence;
import org.eclipse.jface.bindings.keys.KeySequenceText;
import org.eclipse.jface.bindings.keys.ParseException;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.tests.harness.util.UITestCase;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.JUnit4;

/**
 * Tests Bug 43168
 *
 * @since 3.0
 */
@RunWith(JUnit4.class)
public class Bug43168Test extends UITestCase {

	/**
	 * Constructor for Bug43168Test.
	 */
	public Bug43168Test() {
		super(Bug43168Test.class.getSimpleName());
	}

	/**
	 * Tests that a <code>StackOverflowError</code> does not occur when
	 * trying to set the key sequence in a key sequence entry widget.
	 *
	 * @throws ParseException
	 *             If "CTRL+" is not recognized as a key sequence.
	 */
	@Test
	public void testStackOverflow() throws ParseException {
		Display display = Display.getCurrent();
		Shell shell = new Shell(display);
		shell.setLayout(new RowLayout());
		Text text = new Text(shell, SWT.BORDER);
		KeySequenceText keySequenceText = new KeySequenceText(text);

		shell.pack();
		shell.open();
		keySequenceText.setKeySequence(KeySequence.getInstance("CTRL+")); //$NON-NLS-1$
		shell.close();
	}
}

==> eclipse-platform-ui_4.28.orig.tar.xz: eclipse-platform-ui-4.28/tests/org.eclipse.ui.tests/Eclipse UI Tests/org/eclipse/ui/tests/keys/Bug43168Test.java <==
/*******************************************************************************
 * Copyright (c) 2000, 2006 IBM Corporation and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/

package org.eclipse.ui.tests.keys;

import org.eclipse.jface.bindings.keys.KeySequence;
import org.eclipse.jface.bindings.keys.KeySequenceText;
import org.eclipse.jface.bindings.keys.ParseException;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.RowLayout;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.junit.Test;

/**
 * Tests Bug 43168
 *
 * @since 3.0
 */
public class Bug43168Test {

	/**
	 * Tests that a <code>StackOverflowError</code> does not occur when
	 * trying to set the key sequence in a key sequence entry widget.
	 *
	 * @throws ParseException
	 *             If "CTRL+" is not recognized as a key sequence.
	 */
	@Test
	public void testStackOverflow() throws ParseException {
		Display display = Display.getCurrent();
		Shell shell = new Shell(display);
		shell.setLayout(new RowLayout());
		Text text = new Text(shell, SWT.BORDER);
		KeySequenceText keySequenceText = new KeySequenceText(text);

		shell.pack();
		shell.open();
		keySequenceText.setKeySequence(KeySequence.getInstance("CTRL+")); //$NON-NLS-1$
		shell.close();
	}
}
